#
#   Makefile.PL for ripwrap
#    - version 0.12
#
require 5.008;
use ExtUtils::MakeMaker;
use strict;
use Getopt::Std;
use vars qw($opt_n);
unless (getopts("n")) {
    die "Usage: $0 [-n]\n";
}

# Check for non-standard modules that are used by this library.
$| = 1; # autoflush on

WriteMakefile(
    'DISTNAME'     => 'ripwrap',
    'NAME'         => 'RipWrap',
    'VERSION_FROM' => 'ripwrap',
    'EXE_FILES'    => [ qw(ripwrap) ],
    'clean'        => { FILES => '' },
    'dist'         => { COMPRESS => 'gzip', SUFFIX => 'gz' },
    'PREREQ_PM'    => { 'Gtk2' => 1, 'Glib' => 1 }
);

package MY;

# Pass Glade-Perl version number to pod2man
sub manifypods
{
    my $self = shift;
    my $ver = $self->{'VERSION'} || "";
    local($_) = $self->SUPER::manifypods(@_);
    s/pod2mans*$/pod2man --release ripwrap-$ver/m;
    $_;
}

print "\nRunning additional test to be sure ripwrap will work\n";

print "test for lsdvd: "; 
my $lsdvd = `lsdvd -V 2>&1`;
if ( $lsdvd !~ /0.(\d+)\s/ ) {
die "Not Found!\n\n***************\n" . 
  "RipWrap needs my little app \"lsdvd\" in order to see what is on your dvd\'s\n" .
  "Download it and install it (and libdvdread) before trying to use RipWrap.\n" .
  "If it\'s simply not on your path then set the full path inside RipWrap.\n" .
  "***************\n\n"
}
if ( $1 < 9 ) {
die "Too old!\n\n***************\n" . 
  "RipWrap needs at least version 0.9 of lsdvd, but version 0.$1 was found\n" .
  "Download it and install it (and libdvdread) before trying to use RipWrap.\n" .
  "***************\n\n"
}
print "found\n";

print "test for MPlayer: "; die "Not Found!\n\n***************\n" .
  "RipWrap is based around the MPlayer video player. it has not been found on\n" .
  "your current path. Install it from http://mplayerhq/hu see INSTALL.html or\n" .
  "INSTALL for installation instructions.\n" .
  "***************\n\n" if ( system "mplayer 2&>1 > /dev/null" ); print "found\n";

print "test for MEncoder: "; die "Not Found!\n\n***************\n" .
  "RipWrap uses MEncoder, which is part of MPlayer video player package. This\n" .
  "was not found. Install it from http://mplayerhq/hu see INSTALL.html or\n" .
  "INSTALL for installation instructions.\n" .
  "***************\n\n" if ( system "mencoder -ovc help 2> /dev/null | grep MEncoder > /dev/null" ); print "found\n";

print "test for MP4Box: "; 
if ( system "MP4Box -version &> /dev/null" ) {
    print "Not Found!\n\n***************\n" .
      "RipWrap needs MP4Box in order to write mp4 files. mp4 support can't work\n" .
      "without it. You can get it from most package managers. (I think)\n" .
      "***************\n\n" ; 
} else {
    print "found\n";
}

print "Check complete, it will run...\n"; 


print "\nPlease send any feedback to me, I actually do want to know what you think of it.";
print "\nMaybe then I can make it suck less. shamgar03\@users.sourceforge.net\n\n"; 

exit(0);

